@@ -50,10 +50,12 @@ class UIImage(UIElement):
     def __init__(self, x: int, y: int, width: int, height: int, image: pygame.Surface):
         super().__init__(x, y, width, height)
         self.image = pygame.transform.scale(image, (width, height))
+        self.rect = image.get_rect()
+        self.rect.center = (x, y)
 
     def render(self, screen: pygame.Surface):
         if self.visible:
-            screen.blit(self.image, self.rect.topleft)
+            screen.blit(self.image, self.rect)
 
 
 class UIButton(UIElement):
